Feature

Trait Feature 

pub trait Feature:
    Display
    + DynClone
    + Debug {
    // Required methods
    fn name(&self) -> &'static str;
    fn translate(&mut self, v: Coordinate<f64>);
    fn edge_union(&self) -> Option<MultiPolygon<f64>>;
    fn interior(&self) -> Vec<InnerAtom>;

    // Provided method
    fn edge_subtract(&self) -> Option<MultiPolygon<f64>> { ... }
}
A top-level unit that makes up the geometry of the panel.

Required Methods

fn name(&self) -> &'static str

Human-readable name describing the construction.

fn translate(&mut self, v: Coordinate<f64>)

Adjust all coordinates by the specified amount. Should affect all geometries returned from Feature::edge_union, Feature::edge_subtract, and Feature::interior.

fn edge_union(&self) -> Option<MultiPolygon<f64>>

Returns the outer geometry describing the boundaries of the panel, which should be unioned with the outer geometry of all other features.

fn interior(&self) -> Vec<InnerAtom>

Returns the inner geometry describing features on the panel, within the bounds of the computed edge geometry.

Provided Methods

fn edge_subtract(&self) -> Option<MultiPolygon<f64>>

Returns the outer geometry describing the boundaries of the panel, which should be subtracted from the outer geometry of all other features.